# DLL (Deep Learning Library)

DLL is a deep learning library inspired by TensorFlow and PyTorch. This is my largest project to date, featuring thousands of lines of code. It encompasses a wide range of deep learning and machine learning methods, and includes numerous examples and tests to demonstrate their usage. Feel free to explore the source code and experiment with the models using the documentation.

## Documentation:

Checkout the documentation of DLL [here](https://naapeli.github.io/deep-learning-library/).

## Upcoming topics:

- embedding layer
- concatenate layer
- multi headed cross attention
- hyperparameter tuning with grid search and random search
- multiclass classification with OvO and OvR

## Running Tests

To run the tests, navigate to the deep-learning-library-folder and use eg. the following command:

```
python -m Tests.ReinforcementLearning.DeepReinforcementLearning
```

Feel free to explore the code and apply it to new problems!
